==> hp-8.x-1.0.tar.gz: hp/src/SettingsForm.php <==
<?php

namespace Drupal\hp;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure user settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'hp_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'hp.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('hp.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('The Human Presence API key.'),
      '#required' => TRUE,
    ];

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Human Presence monitoring via its JavaScript user interaction tracker.'),
      '#default_value' => $config->get('status'),
    ];

    $form['admin_bypass'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Dupal superuser can bypass Human Presence protection.'),
      '#default_value' => $config->get('admin_bypass'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('hp.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('status', $form_state->getValue('status'))
      ->set('admin_bypass', $form_state->getValue('admin_bypass'))
      ->save();
  }

}

==> hp-8.x-1.1.tar.gz: hp/src/SettingsForm.php <==
<?php

namespace Drupal\hp;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure user settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'hp_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'hp.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('hp.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('The Human Presence API key. You can get one at <a target="_blank" href="https://www.humanpresence.io/sign-up.php#Drupal">https://www.humanpresence.io/sign-up.php#Drupal</a>.'),
      '#required' => TRUE,
    ];

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Human Presence monitoring via its JavaScript user interaction tracker.'),
      '#default_value' => $config->get('status'),
    ];

    $form['admin_bypass'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Dupal superuser can bypass Human Presence protection.'),
      '#default_value' => $config->get('admin_bypass'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('hp.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('status', $form_state->getValue('status'))
      ->set('admin_bypass', $form_state->getValue('admin_bypass'))
      ->save();
  }

}
